unit MainUnit;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  StdCtrls, ExtCtrls;

type
  TMainForm = class(TForm)
    Panel1: TPanel;
    GoButton: TButton;
    LogMemo: TMemo;
    procedure GoButtonClick(Sender: TObject);
  private
    { Private declarations }
  public
    { Public declarations }
  end;

var
  MainForm: TMainForm;

implementation

{$R *.DFM}

uses
  AIOUSB;

type
  TUSBAI1616Config = packed record
    ChannelRange: array[$0..$F] of Byte;
    CalibMode: Byte;
    TrigMode: Byte;
    StartStopCH: Byte;
    Oversample: Byte;
    HighChannels: Byte; //added for compatibility with the AI-MUX family
  end;

var
  DeviceIndex: LongWord;
  Config: TUSBAI1616Config;

procedure TMainForm.GoButtonClick(Sender: TObject);
var
  Hz: Double;
  PID,
  ConfigBufSize, L: LongWord;
  ADData: array of Word;
  I, NumReports, TotData: Integer;
  StartTime, ThisTime, DeltaTime, TestTime: Int64;

begin
  DeviceIndex := ResolveDeviceIndex(diFirst);
  if DeviceIndex = diNone then begin
    LogMemo.Lines.Add('No card found.');
    LogMemo.Lines.Add('');
    Exit;
  end;

  QueryDeviceInfo(DeviceIndex, @PID, nil, nil, nil, nil);
  if not (((PID >= $8040) and (PID <= $8044)) or ((PID >= $8140) and (PID <= $8144))) then begin
    LogMemo.Lines.Add('PID ' + IntToHex(PID, 4) + ' is not the card we''re looking for.');
    LogMemo.Lines.Add('');
    Exit;
  end;

  Hz := 0;
  CTR_StartOutputFreq(DeviceIndex, 0, @Hz);

  for I := $0 to $F do
    Config.ChannelRange[I] := 1
  ;
  Config.StartStopCH := $00;
  Config.CalibMode := 0; //Take actual data, not internal calibration sources.
  Config.TrigMode := $00; //Take 1 channel each software start.
  Config.Oversample := 0; //No oversample.
  ConfigBufSize := SizeOf(Config);
  ADC_Initialize(DeviceIndex, @Config, ConfigBufSize, ':1TO1:');

  //Hz := 500000;
  //CTR_StartOutputFreq(DeviceIndex, 0, @Hz);

  AIOUSB_SetStreamingBlockSize(DeviceIndex, 512);

  LogMemo.Lines.Add('Acquiring...');
  NumReports := 0;
  TotData := 0;

  GoButton.Enabled := False;

  QueryPerformanceFrequency(TestTime);
  TestTime := 3 * TestTime;

  QueryPerformanceCounter(StartTime);
  repeat
    SetLength(ADData, 2);
    for I := 0 to High(ADData) do ADData[I] := $000F;
    L := Length(ADData) * SizeOf(ADData[0]);
    GenericVendorRead(DeviceIndex, $BF, 0, $0, L, @ADData[0]);
    QueryPerformanceCounter(ThisTime);
    Inc(NumReports);
    Inc(TotData, ADData[1]);

    DeltaTime := ThisTime - StartTime;
    if DeltaTime > TestTime then Break;
  until False;

  LogMemo.Lines.Add('Acquisition complete.');
  LogMemo.Lines.Add(IntToStr(Round(1/3 * NumReports)) + ' Hz');
  LogMemo.Lines.Add(IntToHex(Round(TotData / NumReports), 4));
  LogMemo.Lines.Add('');
  GoButton.Enabled := True;
end;

end.
